package com.ruoyi.bst.locationLog.service;

import java.util.List;

import com.ruoyi.bst.locationLog.domain.LocationLog;
import com.ruoyi.bst.locationLog.domain.LocationLogQuery;
import com.ruoyi.bst.locationLog.domain.LocationLogVO;
import com.ruoyi.bst.locationLog.domain.vo.LocationLogPositionVO;

/**
 * 定位日志Service接口
 *
 * @author ruoyi
 * @date 2025-03-24
 */
public interface LocationLogService
{
    /**
     * 查询定位日志
     *
     * @param id 定位日志主键
     * @return 定位日志
     */
    public LocationLogVO selectLocationLogById(Long id, boolean scope);

    default LocationLogVO selectLocationLogById(Long id) {
        return selectLocationLogById(id, false);
    }

    /**
     * 查询定位日志列表
     *
     * @param locationLog 定位日志
     * @return 定位日志集合
     */
    public List<LocationLogVO> selectLocationLogList(LocationLogQuery locationLog);
    

    /**
     * 新增定位日志
     *
     * @param locationLog 定位日志
     * @return 结果
     */
    public int insertLocationLog(LocationLog locationLog);

    /**
     * 修改定位日志
     *
     * @param locationLog 定位日志
     * @return 结果
     */
    public int updateLocationLog(LocationLog locationLog);

    /**
     * 批量删除定位日志
     *
     * @param ids 需要删除的定位日志主键集合
     * @return 结果
     */
    public int deleteLocationLogByIds(List<Long> ids);

    /**
     * 批量插入定位日志
     * @param list 定位日志列表
     * @return 插入的行数
     */
    public int batchInsert(List<? extends LocationLog> list);

    /**
     * 根据订单ID查询定位点列表
     * @param orderId 订单ID
     * @return 定位点列表
     */
    public List<LocationLogPositionVO> selectPositionListByOrderId(Long orderId);
}
